# bbmap

**DOI:** [10.5281/zenodo.13810656](https://doi.org/10.5281/zenodo.13810656)

## Available Versions
- **Version 39.1.0**
  - [Download](https://zenodo.org/record/13810658/files/bbmap_39.1.0.img)
  - **MD5:** `3e6c469061a2d45f273b0c24a05140b9`
  - **DOI:** [10.5281/zenodo.13810658](https://doi.org/10.5281/zenodo.13810658)
  - **Size:** 223.38 MB
  - **Binaries:** 0 available

## Binaries (6 total)

```bbmap.sh reformat.sh adadapters.sh bbmerge.sh bbduk.sh bbsplit.sh```
